About
=====

Console app to chck if teachers gave the correct name to the github repository for student assignments when using https://github.com/petarmaric/pjisp-assignment-template.

Installation
============

To install pjisp-template-name run::

    $ pip install pjisp-template-name

Console app usage
=================

    $ pjisp_template_name <template_name>
